==> App-Dochazka-WWW-0.130.tar.gz: App-Dochazka-WWW-0.130/share/js/dochazka-www/dnotice-init.js <==
// ************************************************************************* 
// Copyright (c) 2014-2015, SUSE LLC
// 
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
// 
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
// 
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
// 3. Neither the name of SUSE LLC nor the names of its contributors may be
// used to endorse or promote products derived from this software without
// specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
// ************************************************************************* 
//
// app/dnotice-init.js
//
// Round one of dnotice initialization - called from app/target-init.js
//
"use strict";

define ([
    'current-user',
    'target'
], function (
    currentUser,
    target
) {

    return function () {

        // demo notice from App::MFILE::WWW
        target.push('demoNotice', {
            'name': 'demoNotice',
            'type': 'dnotice',
            'menuText': 'Demo notice',
            'title': 'Demo notice',
            'preamble': 'This is just an illustration',
            'aclProfile': 'passerby',
            'back': 'demoMenu'
        });

        // privHistory listing
        target.push('privHistory', {
            'name': 'privHistory',
            'type': 'dnotice',
            'menuText': 'Privilege history listing (quick)',
            'title': 'History of privlevel changes for employee ' + currentUser().obj.nick,
            'preamble': '<span style="text-decoration: underline">Effective date/time</span>' +
                        '&nbsp;&nbsp;&nbsp;' +
                        '<span style="text-decoration: underline">Priv level&nbsp;&nbsp;</span>',
            'aclProfile': 'admin',
            'back': 'mainPriv'
        });

    };

});

==> App-Dochazka-WWW-0.139.tar.gz: App-Dochazka-WWW-0.139/share/js/dochazka-www/dnotice-init.js <==
// ************************************************************************* 
// Copyright (c) 2014-2015, SUSE LLC
// 
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
// 
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
// 
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
// 3. Neither the name of SUSE LLC nor the names of its contributors may be
// used to endorse or promote products derived from this software without
// specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
// ************************************************************************* 
//
// app/dnotice-init.js
//
// Round one of dnotice initialization - called from app/target-init.js
//
"use strict";

define ([
    'current-user',
    'target'
], function (
    currentUser,
    target
) {

    return function () {

        // demo notice from App::MFILE::WWW
        target.push('demoNotice', {
            'name': 'demoNotice',
            'type': 'dnotice',
            'menuText': 'Demo notice',
            'title': 'Demo notice',
            'preamble': 'This is just an illustration',
            'aclProfile': 'passerby',
            'back': 'demoMenu'
        });

        // privHistory listing
        target.push('privHistory', {
            'name': 'privHistory',
            'type': 'dnotice',
            'menuText': 'Priv (status) history',
            'title': 'Priv (status) history',
            'preamble': '<span style="text-decoration: underline">Effective date/time</span>' +
                        '&nbsp;&nbsp;&nbsp;' +
                        '<span style="text-decoration: underline">Priv level&nbsp;&nbsp;</span>',
            'aclProfile': 'passerby',
            'back': 'mainPriv'
        });

    };

});
